test: add gpiohandle mock impl

Add gpio handle mock implementation for use in testing.

Change-Id: I0fb2d1af4739ad700f62a4e7cbbe62db528bb93e
Signed-off-by: Patrick Venture <venture@google.com>
diff --git a/gpio_handle.hpp b/gpio_handle.hpp
index f7d4a5e..f48a34d 100644
--- a/gpio_handle.hpp
+++ b/gpio_handle.hpp
@@ -12,9 +12,9 @@
  *
  * @param[in] gpiochip - gpiochip id as string, e.g. "0", or "1"
  * @param[in] line - gpio line offset as string.
  * @return A gpioplus::Handle on success nullptr on failure.
  */
-std::unique_ptr<gpioplus::Handle> BuildGpioHandle(const std::string& gpiochip,
-                                                  const std::string& line);
+std::unique_ptr<gpioplus::HandleInterface>
+    BuildGpioHandle(const std::string& gpiochip, const std::string& line);
 
 } // namespace gpio
@@ -12,9 +12,9 @@
  * @param[in] gpiochip - gpiochip id as string, e.g. "0", or "1"
  * @param[in] line - gpio line offset as string.
- * @return A gpioplus::Handle on success nullptr on failure.
+ * @return A gpioplus::HandleInterface on success nullptr on failure.
  */